# ezcv

Hi, welcome to [ezcv](https://ezcv.readthedocs.io/en/latest/). This is a batteries-included static site generator

## Getting started

Everything you need to get up and running.

### Requirements

To get started you will need python 3.8+ and pip for that python version. Once you have that you will need to install ezcv `pip install ezcv`

### Running the project

You can preview your project using `ezcv -p`, and generate your project fully using `ezcv build` which will build the site to `/site`. You can also set it to minify the output files to improve your performance on the site using `ezcv build -o` (this takes longer to build).

### Additional documentation

There is additional documentation available that will be helpful to you:

- [List of themes for ezcv](https://ezcv.readthedocs.io/en/latest/included-themes/)
- [ezcv usage guide](https://ezcv.readthedocs.io/en/latest/usage/)
- [cli documentation for ezcv](https://ezcv.readthedocs.io/en/latest/cli/)
